@@ -133,10 +133,21 @@ typedef struct
     int         mode;
 } XIValuatorClassInfo;
 
+/* new in XI 2.1 */
+typedef struct
+{
+    int         type;
+    int         sourceid;
+    int         number;
+    int         scroll_type;
+    double      increment;
+    int         flags;
+} XIScrollClassInfo;
+
 typedef struct
 {
     int                 deviceid;
-    char*               name;
+    char                *name;
     int                 use;
     int                 attachment;
     Bool                enabled;
@@ -242,7 +253,7 @@ typedef struct {
     int           evtype;       /* XI_RawKeyPress, XI_RawKeyRelease, etc. */
     Time          time;
     int           deviceid;
-    int           sourceid;
+    int           sourceid;     /* Bug: Always 0. https://bugs.freedesktop.org//show_bug.cgi?id=34240 */
     int           detail;
     int           flags;
     XIValuatorState valuators;
@@ -314,12 +325,12 @@ extern Bool     XIWarpPointer(
     int                 deviceid,
     Window              src_win,
     Window              dst_win,
-    int                 src_x,
-    int                 src_y,
+    double              src_x,
+    double              src_y,
     unsigned int        src_width,
     unsigned int        src_height,
-    int                 dst_x,
-    int                 dst_y
+    double              dst_x,
+    double              dst_y
 );
 
 extern Status   XIDefineCursor(
